/*
 * mtx2dasm.h - Decode MTX BASIC from a snap file
 *
 * Copyright (C) 2012 Paul Daniels <paul.daniels40@yahoo.co.uk>
 *
 * Version of dasm.h adapted for mtx2bas. 
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * 19/05/12 - PD General code tidy up.
 *
 */

static char *Mnemonics[256] =
{
  "NOP","LD BC,~","LD (BC),A","INC BC","INC B","DEC B","LD B,*","RLCA",
  "EX AF,AF'","ADD HL,BC","LD A,(BC)","DEC BC","INC C","DEC C","LD C,*","RRCA",
  "DJNZ @","LD DE,~","LD (DE),A","INC DE","INC D","DEC D","LD D,*","RLA",
  "JR @","ADD HL,DE","LD A,(DE)","DEC DE","INC E","DEC E","LD E,*","RRA",
  "JR NZ,@","LD HL,~","LD (~),HL","INC HL","INC H","DEC H","LD H,*","DAA",
  "JR Z,@","ADD HL,HL","LD HL,(~)","DEC HL","INC L","DEC L","LD L,*","CPL",
  "JR NC,@","LD SP,~","LD (~),A","INC SP","INC (HL)","DEC (HL)","LD (HL),*","SCF",
  "JR C,@","ADD HL,SP","LD A,(~)","DEC SP","INC A","DEC A","LD A,*","CCF",
  "LD B,B","LD B,C","LD B,D","LD B,E","LD B,H","LD B,L","LD B,(HL)","LD B,A",
  "LD C,B","LD C,C","LD C,D","LD C,E","LD C,H","LD C,L","LD C,(HL)","LD C,A",
  "LD D,B","LD D,C","LD D,D","LD D,E","LD D,H","LD D,L","LD D,(HL)","LD D,A",
  "LD E,B","LD E,C","LD E,D","LD E,E","LD E,H","LD E,L","LD E,(HL)","LD E,A",
  "LD H,B","LD H,C","LD H,D","LD H,E","LD H,H","LD H,L","LD H,(HL)","LD H,A",
  "LD L,B","LD L,C","LD L,D","LD L,E","LD L,H","LD L,L","LD L,(HL)","LD L,A",
  "LD (HL),B","LD (HL),C","LD (HL),D","LD (HL),E","LD (HL),H","LD (HL),L","HALT","LD (HL),A",
  "LD A,B","LD A,C","LD A,D","LD A,E","LD A,H","LD A,L","LD A,(HL)","LD A,A",
  "ADD A,B","ADD A,C","ADD A,D","ADD A,E","ADD A,H","ADD A,L","ADD A,(HL)","ADD A,A",
  "ADC A,B","ADC A,C","ADC A,D","ADC A,E","ADC A,H","ADC A,L","ADC A,(HL)","ADC A,A",
  "SUB A,B","SUB A,C","SUB A,D","SUB A,E","SUB A,H","SUB A,L","SUB A,(HL)","SUB A,A",
  "SBC A,B","SBC A,C","SBC A,D","SBC A,E","SBC A,H","SBC A,L","SBC A,(HL)","SBC A,A",
  "AND A,B","AND A,C","AND A,D","AND A,E","AND A,H","AND A,L","AND A,(HL)","AND A,A",
  "XOR A,B","XOR A,C","XOR A,D","XOR A,E","XOR A,H","XOR A,L","XOR A,(HL)","XOR A,A",
  "OR A,B","OR A,C","OR A,D","OR A,E","OR A,H","OR A,L","OR A,(HL)","OR A,A",
  "CP A,B","CP A,C","CP A,D","CP A,E","CP A,H","CP A,L","CP A,(HL)","CP A,A",
  "RET NZ","POP BC","JP NZ,~","JP ~","CALL NZ,~","PUSH BC","ADD A,*","RST 0x00",
  "RET Z","RET","JP Z,~","PFX_CB","CALL Z,~","CALL ~","ADC A,*","RST 0x08",
  "RET NC","POP DE","JP NC,~","OUT A,(*)","CALL NC,~","PUSH DE","SUB A,*","RST 0x10",
  "RET C","EXX","JP C,~","IN A,(*)","CALL C,~","PFX_DD","SBC A,*","RST 0x18",
  "RET PO","POP HL","JP PO,~","EX HL,(SP)","CALL PO,~","PUSH HL","AND A,*","RST 0x20",
  "RET PE","LD PC,HL","JP PE,~","EX DE,HL","CALL PE,~","PFX_ED","XOR A,*","RST 0x28",
  "RET P","POP AF","JP P,~","DI","CALL P,~","PUSH AF","OR A,*","RST 0x30",
  "RET M","LD SP,HL","JP M,~","EI","CALL M,~","PFX_FD","CP A,*","RST 0x38"
};

static char *MnemonicsCB[256] =
{
  "RLC B","RLC C","RLC D","RLC E","RLC H","RLC L","RLC (HL)","RLC A",
  "RRC B","RRC C","RRC D","RRC E","RRC H","RRC L","RRC (HL)","RRC A",
  "RL B","RL C","RL D","RL E","RL H","RL L","RL (HL)","RL A",
  "RR B","RR C","RR D","RR E","RR H","RR L","RR (HL)","RR A",
  "SLA B","SLA C","SLA D","SLA E","SLA H","SLA L","SLA (HL)","SLA A",
  "SRA B","SRA C","SRA D","SRA E","SRA H","SRA L","SRA (HL)","SRA A",
  "SLL B","SLL C","SLL D","SLL E","SLL H","SLL L","SLL (HL)","SLL A",
  "SRL B","SRL C","SRL D","SRL E","SRL H","SRL L","SRL (HL)","SRL A",
  "BIT 0,B","BIT 0,C","BIT 0,D","BIT 0,E","BIT 0,H","BIT 0,L","BIT 0,(HL)","BIT 0,A",
  "BIT 1,B","BIT 1,C","BIT 1,D","BIT 1,E","BIT 1,H","BIT 1,L","BIT 1,(HL)","BIT 1,A",
  "BIT 2,B","BIT 2,C","BIT 2,D","BIT 2,E","BIT 2,H","BIT 2,L","BIT 2,(HL)","BIT 2,A",
  "BIT 3,B","BIT 3,C","BIT 3,D","BIT 3,E","BIT 3,H","BIT 3,L","BIT 3,(HL)","BIT 3,A",
  "BIT 4,B","BIT 4,C","BIT 4,D","BIT 4,E","BIT 4,H","BIT 4,L","BIT 4,(HL)","BIT 4,A",
  "BIT 5,B","BIT 5,C","BIT 5,D","BIT 5,E","BIT 5,H","BIT 5,L","BIT 5,(HL)","BIT 5,A",
  "BIT 6,B","BIT 6,C","BIT 6,D","BIT 6,E","BIT 6,H","BIT 6,L","BIT 6,(HL)","BIT 6,A",
  "BIT 7,B","BIT 7,C","BIT 7,D","BIT 7,E","BIT 7,H","BIT 7,L","BIT 7,(HL)","BIT 7,A",
  "RES 0,B","RES 0,C","RES 0,D","RES 0,E","RES 0,H","RES 0,L","RES 0,(HL)","RES 0,A",
  "RES 1,B","RES 1,C","RES 1,D","RES 1,E","RES 1,H","RES 1,L","RES 1,(HL)","RES 1,A",
  "RES 2,B","RES 2,C","RES 2,D","RES 2,E","RES 2,H","RES 2,L","RES 2,(HL)","RES 2,A",
  "RES 3,B","RES 3,C","RES 3,D","RES 3,E","RES 3,H","RES 3,L","RES 3,(HL)","RES 3,A",
  "RES 4,B","RES 4,C","RES 4,D","RES 4,E","RES 4,H","RES 4,L","RES 4,(HL)","RES 4,A",
  "RES 5,B","RES 5,C","RES 5,D","RES 5,E","RES 5,H","RES 5,L","RES 5,(HL)","RES 5,A",
  "RES 6,B","RES 6,C","RES 6,D","RES 6,E","RES 6,H","RES 6,L","RES 6,(HL)","RES 6,A",
  "RES 7,B","RES 7,C","RES 7,D","RES 7,E","RES 7,H","RES 7,L","RES 7,(HL)","RES 7,A",
  "SET 0,B","SET 0,C","SET 0,D","SET 0,E","SET 0,H","SET 0,L","SET 0,(HL)","SET 0,A",
  "SET 1,B","SET 1,C","SET 1,D","SET 1,E","SET 1,H","SET 1,L","SET 1,(HL)","SET 1,A",
  "SET 2,B","SET 2,C","SET 2,D","SET 2,E","SET 2,H","SET 2,L","SET 2,(HL)","SET 2,A",
  "SET 3,B","SET 3,C","SET 3,D","SET 3,E","SET 3,H","SET 3,L","SET 3,(HL)","SET 3,A",
  "SET 4,B","SET 4,C","SET 4,D","SET 4,E","SET 4,H","SET 4,L","SET 4,(HL)","SET 4,A",
  "SET 5,B","SET 5,C","SET 5,D","SET 5,E","SET 5,H","SET 5,L","SET 5,(HL)","SET 5,A",
  "SET 6,B","SET 6,C","SET 6,D","SET 6,E","SET 6,H","SET 6,L","SET 6,(HL)","SET 6,A",
  "SET 7,B","SET 7,C","SET 7,D","SET 7,E","SET 7,H","SET 7,L","SET 7,(HL)","SET 7,A"
};

static char *MnemonicsED[256] =
{
  "DB 0xED,0x00","DB 0xED,0x01","DB 0xED,0x02","DB 0xED,0x03",
  "DB 0xED,0x04","DB 0xED,0x05","DB 0xED,0x06","DB 0xED,0x07",
  "DB 0xED,0x08","DB 0xED,0x09","DB 0xED,0x0A","DB 0xED,0x0B",
  "DB 0xED,0x0C","DB 0xED,0x0D","DB 0xED,0x0E","DB 0xED,0x0F",
  "DB 0xED,0x10","DB 0xED,0x11","DB 0xED,0x12","DB 0xED,0x13",
  "DB 0xED,0x14","DB 0xED,0x15","DB 0xED,0x16","DB 0xED,0x17",
  "DB 0xED,0x18","DB 0xED,0x19","DB 0xED,0x1A","DB 0xED,0x1B",
  "DB 0xED,0x1C","DB 0xED,0x1D","DB 0xED,0x1E","DB 0xED,0x1F",
  "DB 0xED,0x20","DB 0xED,0x21","DB 0xED,0x22","DB 0xED,0x23",
  "DB 0xED,0x24","DB 0xED,0x25","DB 0xED,0x26","DB 0xED,0x27",
  "DB 0xED,0x28","DB 0xED,0x29","DB 0xED,0x2A","DB 0xED,0x2B",
  "DB 0xED,0x2C","DB 0xED,0x2D","DB 0xED,0x2E","DB 0xED,0x2F",
  "DB 0xED,0x30","DB 0xED,0x31","DB 0xED,0x32","DB 0xED,0x33",
  "DB 0xED,0x34","DB 0xED,0x35","DB 0xED,0x36","DB 0xED,0x37",
  "DB 0xED,0x38","DB 0xED,0x39","DB 0xED,0x3A","DB 0xED,0x3B",
  "DB 0xED,0x3C","DB 0xED,0x3D","DB 0xED,0x3E","DB 0xED,0x3F",
  "IN B,(C)","OUT (C),B","SBC HL,BC","LD (~),BC",
  "NEG","RETN","IM 0","LD I,A",
  "IN C,(C)","OUT (C),C","ADC HL,BC","LD BC,(~)",
  "DB 0xED,0x4C","RETI","DB 0xED,0x4E","LD R,A",
  "IN D,(C)","OUT (C),D","SBC HL,DE","LD (~),DE",
  "DB 0xED,0x54","DB 0xED,0x55","IM 1","LD A,I",
  "IN E,(C)","OUT (C),E","ADC HL,DE","LD DE,(~)",
  "DB 0xED,0x5C","DB 0xED,0x5D","IM 2","LD A,R",
  "IN H,(C)","OUT (C),H","SBC HL,HL","LD (~),HL",
  "DB 0xED,0x64","DB 0xED,0x65","DB 0xED,0x66","RRD",
  "IN L,(C)","OUT (C),L","ADC HL,HL","LD HL,(~)",
  "DB 0xED,0x6C","DB 0xED,0x6D","DB 0xED,0x6E","RLD",
  "IN F,(C)","DB 0xED,0x71","SBC HL,SP","LD (~),SP",
  "DB 0xED,0x74","DB 0xED,0x75","DB 0xED,0x76","DB 0xED,0x77",
  "IN A,(C)","OUT (C),A","ADC HL,SP","LD SP,(~)",
  "DB 0xED,0x7C","DB 0xED,0x7D","DB 0xED,0x7E","DB 0xED,0x7F",
  "DB 0xED,0x80","DB 0xED,0x81","DB 0xED,0x82","DB 0xED,0x83",
  "DB 0xED,0x84","DB 0xED,0x85","DB 0xED,0x86","DB 0xED,0x87",
  "DB 0xED,0x88","DB 0xED,0x89","DB 0xED,0x8A","DB 0xED,0x8B",
  "DB 0xED,0x8C","DB 0xED,0x8D","DB 0xED,0x8E","DB 0xED,0x8F",
  "DB 0xED,0x90","DB 0xED,0x91","DB 0xED,0x92","DB 0xED,0x93",
  "DB 0xED,0x94","DB 0xED,0x95","DB 0xED,0x96","DB 0xED,0x97",
  "DB 0xED,0x98","DB 0xED,0x99","DB 0xED,0x9A","DB 0xED,0x9B",
  "DB 0xED,0x9C","DB 0xED,0x9D","DB 0xED,0x9E","DB 0xED,0x9F",
  "LDI","CPI","INI","OUTI",
  "DB 0xED,0xA4","DB 0xED,0xA5","DB 0xED,0xA6","DB 0xED,0xA7",
  "LDD","CPD","IND","OUTD",
  "DB 0xED,0xAC","DB 0xED,0xAD","DB 0xED,0xAE","DB 0xED,0xAF",
  "LDIR","CPIR","INIR","OTIR",
  "DB 0xED,0xB4","DB 0xED,0xB5","DB 0xED,0xB6","DB 0xED,0xB7",
  "LDDR","CPDR","INDR","OTDR",
  "DB 0xED,0xBC","DB 0xED,0xBD","DB 0xED,0xBE","DB 0xED,0xBF",
  "DB 0xED,0xC0","DB 0xED,0xC1","DB 0xED,0xC2","DB 0xED,0xC3",
  "DB 0xED,0xC4","DB 0xED,0xC5","DB 0xED,0xC6","DB 0xED,0xC7",
  "DB 0xED,0xC8","DB 0xED,0xC9","DB 0xED,0xCA","DB 0xED,0xCB",
  "DB 0xED,0xCC","DB 0xED,0xCD","DB 0xED,0xCE","DB 0xED,0xCF",
  "DB 0xED,0xD0","DB 0xED,0xD1","DB 0xED,0xD2","DB 0xED,0xD3",
  "DB 0xED,0xD4","DB 0xED,0xD5","DB 0xED,0xD6","DB 0xED,0xD7",
  "DB 0xED,0xD8","DB 0xED,0xD9","DB 0xED,0xDA","DB 0xED,0xDB",
  "DB 0xED,0xDC","DB 0xED,0xDD","DB 0xED,0xDE","DB 0xED,0xDF",
  "DB 0xED,0xE0","DB 0xED,0xE1","DB 0xED,0xE2","DB 0xED,0xE3",
  "DB 0xED,0xE4","DB 0xED,0xE5","DB 0xED,0xE6","DB 0xED,0xE7",
  "DB 0xED,0xE8","DB 0xED,0xE9","DB 0xED,0xEA","DB 0xED,0xEB",
  "DB 0xED,0xEC","DB 0xED,0xED","DB 0xED,0xEE","DB 0xED,0xEF",
  "DB 0xED,0xF0","DB 0xED,0xF1","DB 0xED,0xF2","DB 0xED,0xF3",
  "DB 0xED,0xF4","DB 0xED,0xF5","DB 0xED,0xF6","DB 0xED,0xF7",
  "DB 0xED,0xF8","DB 0xED,0xF9","DB 0xED,0xFA","DB 0xED,0xFB",
  "DB 0xED,0xFC","DB 0xED,0xFD","DB 0xED,0xFE","DB 0xED,0xFF"
};

static char *MnemonicsXX[256] =
{
  "NOP","LD BC,~","LD (BC),A","INC BC","INC B","DEC B","LD B,*","RLCA",
  "EX AF,AF'","ADD I%,BC","LD A,(BC)","DEC BC","INC C","DEC C","LD C,*","RRCA",
  "DJNZ @","LD DE,~","LD (DE),A","INC DE","INC D","DEC D","LD D,*","RLA",
  "JR @","ADD I%,DE","LD A,(DE)","DEC DE","INC E","DEC E","LD E,*","RRA",
  "JR NZ,@","LD I%,~","LD (~),I%","INC I%","INC I%h","DEC I%h","LD I%h,*","DAA",
  "JR Z,@","ADD I%,I%","LD I%,(~)","DEC I%","INC I%l","DEC I%l","LD I%l,*","CPL",
  "JR NC,@","LD SP,~","LD (~),A","INC SP","INC (I%+^)","DEC (I%+^)","LD (I%+^),*","SCF",
  "JR C,@","ADD I%,SP","LD A,(~)","DEC SP","INC A","DEC A","LD A,*","CCF",
  "LD B,B","LD B,C","LD B,D","LD B,E","LD B,I%h","LD B,I%l","LD B,(I%+^)","LD B,A",
  "LD C,B","LD C,C","LD C,D","LD C,E","LD C,I%h","LD C,I%l","LD C,(I%+^)","LD C,A",
  "LD D,B","LD D,C","LD D,D","LD D,E","LD D,I%h","LD D,I%l","LD D,(I%+^)","LD D,A",
  "LD E,B","LD E,C","LD E,D","LD E,E","LD E,I%h","LD E,I%l","LD E,(I%+^)","LD E,A",
  "LD I%h,B","LD I%h,C","LD I%h,D","LD I%h,E","LD I%h,I%h","LD I%h,I%l","LD H,(I%+^)","LD I%h,A",
  "LD I%l,B","LD I%l,C","LD I%l,D","LD I%l,E","LD I%l,I%h","LD I%l,I%l","LD L,(I%+^)","LD I%l,A",
  "LD (I%+^),B","LD (I%+^),C","LD (I%+^),D","LD (I%+^),E","LD (I%+^),H","LD (I%+^),L","HALT","LD (I%+^),A",
  "LD A,B","LD A,C","LD A,D","LD A,E","LD A,I%h","LD A,I%l","LD A,(I%+^)","LD A,A",
  "ADD A,B","ADD A,C","ADD A,D","ADD A,E","ADD A,I%h","ADD A,I%l","ADD A,(I%+^)","ADD A,A",
  "ADC A,B","ADC A,C","ADC A,D","ADC A,E","ADC A,I%h","ADC A,I%l","ADC A,(I%+^)","ADC,A,A",
  "SUB A,B","SUB A,C","SUB A,D","SUB A,E","SUB A,I%h","SUB A,I%l","SUB A,(I%+^)","SUB A,A",
  "SBC A,B","SBC A,C","SBC A,D","SBC A,E","SBC A,I%h","SBC A,I%l","SBC A,(I%+^)","SBC A,A",
  "AND A,B","AND A,C","AND A,D","AND A,E","AND A,I%h","AND A,I%l","AND A,(I%+^)","AND A,A",
  "XOR A,B","XOR A,C","XOR A,D","XOR A,E","XOR A,I%h","XOR A,I%l","XOR A,(I%+^)","XOR A,A",
  "OR A,B","OR A,C","OR A,D","OR A,E","OR A,I%h","OR A,I%l","OR A,(I%+^)","OR A,A",
  "CP A,B","CP A,C","CP A,D","CP A,E","CP A,I%h","CP A,I%l","CP A,(I%+^)","CP A,A",
  "RET NZ","POP BC","JP NZ,~","JP ~","CALL NZ,~","PUSH BC","ADD *","RST 0x00",
  "RET Z","RET","JP Z,~","PFX_CB","CALL Z,~","CALL ~","ADC A,*","RST 0x08",
  "RET NC","POP DE","JP NC,~","OUT A,(*)","CALL NC,~","PUSH DE","SUB A,*","RST 0x10",
  "RET C","EXX","JP C,~","IN A,(*)","CALL C,~","PFX_DD","SBC A,*","RST 0x18",
  "RET PO","POP I%","JP PO,~","EX I%,(SP)","CALL PO,~","PUSH I%","AND A,*","RST 0x20",
  "RET PE","LD PC,I%","JP PE,~","EX DE,I%","CALL PE,~","PFX_ED","XOR A,*","RST 0x28",
  "RET P","POP AF","JP P,~","DI","CALL P,~","PUSH AF","OR A,*","RST 0x30",
  "RET M","LD SP,I%","JP M,~","EI","CALL M,~","PFX_FD","CP A,*","RST 0x38"
};

static char *MnemonicsXCB[256] =
{
  "RLC B","RLC C","RLC D","RLC E","RLC H","RLC L","RLC (I%@)","RLC A",
  "RRC B","RRC C","RRC D","RRC E","RRC H","RRC L","RRC (I%@)","RRC A",
  "RL B","RL C","RL D","RL E","RL H","RL L","RL (I%@)","RL A",
  "RR B","RR C","RR D","RR E","RR H","RR L","RR (I%@)","RR A",
  "SLA B","SLA C","SLA D","SLA E","SLA H","SLA L","SLA (I%@)","SLA A",
  "SRA B","SRA C","SRA D","SRA E","SRA H","SRA L","SRA (I%@)","SRA A",
  "SLL B","SLL C","SLL D","SLL E","SLL H","SLL L","SLL (I%@)","SLL A",
  "SRL B","SRL C","SRL D","SRL E","SRL H","SRL L","SRL (I%@)","SRL A",
  "BIT 0,B","BIT 0,C","BIT 0,D","BIT 0,E","BIT 0,H","BIT 0,L","BIT 0,(I%@)","BIT 0,A",
  "BIT 1,B","BIT 1,C","BIT 1,D","BIT 1,E","BIT 1,H","BIT 1,L","BIT 1,(I%@)","BIT 1,A",
  "BIT 2,B","BIT 2,C","BIT 2,D","BIT 2,E","BIT 2,H","BIT 2,L","BIT 2,(I%@)","BIT 2,A",
  "BIT 3,B","BIT 3,C","BIT 3,D","BIT 3,E","BIT 3,H","BIT 3,L","BIT 3,(I%@)","BIT 3,A",
  "BIT 4,B","BIT 4,C","BIT 4,D","BIT 4,E","BIT 4,H","BIT 4,L","BIT 4,(I%@)","BIT 4,A",
  "BIT 5,B","BIT 5,C","BIT 5,D","BIT 5,E","BIT 5,H","BIT 5,L","BIT 5,(I%@)","BIT 5,A",
  "BIT 6,B","BIT 6,C","BIT 6,D","BIT 6,E","BIT 6,H","BIT 6,L","BIT 6,(I%@)","BIT 6,A",
  "BIT 7,B","BIT 7,C","BIT 7,D","BIT 7,E","BIT 7,H","BIT 7,L","BIT 7,(I%@)","BIT 7,A",
  "RES 0,B","RES 0,C","RES 0,D","RES 0,E","RES 0,H","RES 0,L","RES 0,(I%@)","RES 0,A",
  "RES 1,B","RES 1,C","RES 1,D","RES 1,E","RES 1,H","RES 1,L","RES 1,(I%@)","RES 1,A",
  "RES 2,B","RES 2,C","RES 2,D","RES 2,E","RES 2,H","RES 2,L","RES 2,(I%@)","RES 2,A",
  "RES 3,B","RES 3,C","RES 3,D","RES 3,E","RES 3,H","RES 3,L","RES 3,(I%@)","RES 3,A",
  "RES 4,B","RES 4,C","RES 4,D","RES 4,E","RES 4,H","RES 4,L","RES 4,(I%@)","RES 4,A",
  "RES 5,B","RES 5,C","RES 5,D","RES 5,E","RES 5,H","RES 5,L","RES 5,(I%@)","RES 5,A",
  "RES 6,B","RES 6,C","RES 6,D","RES 6,E","RES 6,H","RES 6,L","RES 6,(I%@)","RES 6,A",
  "RES 7,B","RES 7,C","RES 7,D","RES 7,E","RES 7,H","RES 7,L","RES 7,(I%@)","RES 7,A",
  "SET 0,B","SET 0,C","SET 0,D","SET 0,E","SET 0,H","SET 0,L","SET 0,(I%@)","SET 0,A",
  "SET 1,B","SET 1,C","SET 1,D","SET 1,E","SET 1,H","SET 1,L","SET 1,(I%@)","SET 1,A",
  "SET 2,B","SET 2,C","SET 2,D","SET 2,E","SET 2,H","SET 2,L","SET 2,(I%@)","SET 2,A",
  "SET 3,B","SET 3,C","SET 3,D","SET 3,E","SET 3,H","SET 3,L","SET 3,(I%@)","SET 3,A",
  "SET 4,B","SET 4,C","SET 4,D","SET 4,E","SET 4,H","SET 4,L","SET 4,(I%@)","SET 4,A",
  "SET 5,B","SET 5,C","SET 5,D","SET 5,E","SET 5,H","SET 5,L","SET 5,(I%@)","SET 5,A",
  "SET 6,B","SET 6,C","SET 6,D","SET 6,E","SET 6,H","SET 6,L","SET 6,(I%@)","SET 6,A",
  "SET 7,B","SET 7,C","SET 7,D","SET 7,E","SET 7,H","SET 7,L","SET 7,(I%@)","SET 7,A"
};

